@@ -1,6 +1,5 @@
 package org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column;
 
-
 /**
  * 
  * @author "Giancarlo Panichi" <a
@@ -25,8 +24,12 @@ public enum ColumnTypeCode {
 	public String toString() {
 		return id;
 	}
+	
+	public String getId(){
+		return id;
+	}
 
-	public String getColumnTypeCodeLabel() {
+	public String getLabel() {
 		switch (this) {
 		case ANNOTATION:
 			return "Annotation";
@@ -50,4 +53,22 @@ public enum ColumnTypeCode {
 
 	}
 
+	
+	/**
+	 * 
+	 * @param id
+	 * @return
+	 */
+	public static ColumnTypeCode getColumnTypeCodeFromId(String id) {
+		if(id==null|| id.isEmpty()) return null;
+		
+		for (ColumnTypeCode columnTypeCode : values()) {
+			if (columnTypeCode.id.compareToIgnoreCase(id) == 0) {
+				return columnTypeCode;
+			}
+		}
+		return null;
+	
+	}
+
 }
